@@ -36,8 +36,10 @@ bool find_chessboard_corners_from_image_array_C( // in
                                                 // good scaling level. Try this first
                                                 int image_pyramid_level,
                                                 bool doblobs,
+                                                bool debug,
 
-                                                bool (*add_points)(int* xy, int N, double scale) )
+                                                bool (*add_points)(int* xy, int N, double scale, void* cookie),
+                                                void* cookie )
 {
     cv::Mat cvimage(Nrows, Ncols, CV_8UC1,
                     imagebuffer, stride);
@@ -54,7 +56,8 @@ bool find_chessboard_corners_from_image_array_C( // in
     }
     else
     {
-        result = find_chessboard_corners_from_image_array( &out_points, cvimage, image_pyramid_level );
+        result = find_chessboard_corners_from_image_array( &out_points, cvimage, image_pyramid_level,
+                                                           debug );
     }
     if( !result ) return false;
 
@@ -62,7 +65,8 @@ bool find_chessboard_corners_from_image_array_C( // in
                    "add_points() assumes PointInt is simply 2 ints");
     return
         (*add_points)( &out_points[0].x, (int)out_points.size(),
-                       1. / (double)FIND_GRID_SCALE);
+                       1. / (double)FIND_GRID_SCALE,
+                       cookie);
 }
 
 extern "C"
@@ -78,14 +82,27 @@ bool find_chessboard_from_image_array_C( // in
                                         // good scaling level. Try this first
                                         int image_pyramid_level,
                                         bool doblobs,
+                                        bool debug,
+                                        int debug_sequence_x,
+                                        int debug_sequence_y,
 
-                                        bool (*add_points)(double* xy, int N) )
+                                        bool (*add_points)(double* xy, int N, void* cookie),
+                                        void* cookie )
 {
     cv::Mat cvimage(Nrows, Ncols, CV_8UC1,
                     imagebuffer, stride);
 
     std::vector<mrgingham::PointDouble> out_points;
 
+    mrgingham::debug_sequence_t debug_sequence = {};
+    if(debug_sequence_x >= 0 &&
+       debug_sequence_y >= 0)
+    {
+        debug_sequence.dodebug = true;
+        debug_sequence.pt.x = debug_sequence_x;
+        debug_sequence.pt.y = debug_sequence_y;
+    }
+
     bool result;
     if(doblobs)
     {
@@ -93,7 +110,9 @@ bool find_chessboard_from_image_array_C( // in
             return false;
 
         result = find_circle_grid_from_image_array(out_points,
-                                                   cvimage, gridn);
+                                                   cvimage, gridn,
+                                                   debug,
+                                                   debug_sequence);
     }
     else
     {
@@ -103,7 +122,10 @@ bool find_chessboard_from_image_array_C( // in
                                                &refinement_level,
                                                gridn,
                                                cvimage,
-                                               image_pyramid_level ) >= 0);
+                                               image_pyramid_level,
+                                               debug,
+                                               debug_sequence,
+                                               NULL ) >= 0);
         free(refinement_level);
     }
     if( !result ) return false;
@@ -111,5 +133,6 @@ bool find_chessboard_from_image_array_C( // in
     static_assert( sizeof(mrgingham::PointDouble) == 2*sizeof(double),
                    "add_points() assumes PointDouble is simply 2 doubles");
     return
-        (*add_points)( &out_points[0].x, (int)out_points.size() );
+        (*add_points)( &out_points[0].x, (int)out_points.size(),
+                       cookie);
 }
